..
 This work is licensed under a Creative Commons Attribution 3.0 Unported
 License.

 http://creativecommons.org/licenses/by/3.0/legalcode

==================
(Placeholder Spec)
==================

This file is just a placeholder for Ocata specs directory.
It will be removed soon after some spec for Ocata is merged.

The latest spec template is found at ``specs/template.rst``
in the ``networking-dpm`` repository.

Problem Description
===================

Sphinx toctree complains if no file exists in a directory
specified in toctree glob.

Proposed Change
===============

Add this file.

References
==========

None.
